@@ -20,16 +20,16 @@
  ***************************************************************************/
 
 // KDE headers:
-#include <kaboutapplication.h>
-#include <kapplication.h>
+#include <tdeaboutapplication.h>
+#include <tdeapplication.h>
 #include <kaudioplayer.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kiconloader.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <knotifyclient.h>
 #include <knotifydialog.h>
 #include <kpassivepopup.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 
 // other TQt headers:
 #include <tqcursor.h>
@@ -67,7 +67,7 @@ kpowersave::kpowersave( bool force_acpi_check, bool trace_func ) : KSystemTray(0
 
 	resume_result = 0;
 
-	config = KGlobal::config();
+	config = TDEGlobal::config();
 	config->setGroup("General");
 	if(!config->readBoolEntry("AlreadyStarted", false) || force_acpi_check){
 		config->writeEntry("AlreadyStarted", true);
@@ -196,9 +196,9 @@ void kpowersave::initMenu() {
 	speed_menu->insertItem(i18n("Dynamic"), DYNAMIC);
 	speed_menu->insertItem(i18n("Powersave"), POWERSAVE);
 
-	CPUFRETQ_SEPARATOR_MENU_ID = contextMenu()->insertSeparator();
+	CPUFREQ_SEPARATOR_MENU_ID = contextMenu()->insertSeparator();
 
-	CPUFRETQ_MENU_ID = contextMenu()->insertItem(i18n("Set CPU Frequency Policy"), speed_menu);
+	CPUFREQ_MENU_ID = contextMenu()->insertItem(i18n("Set CPU Frequency Policy"), speed_menu);
 	connect(speed_menu, TQT_SIGNAL(activated(int)), this, TQT_SLOT(do_setSpeedPolicy(int)));
 	connect(hwinfo, TQT_SIGNAL(currentCPUFreqPolicyChanged()), this, TQT_SLOT(updateCPUFreqMenu()));
 
@@ -361,10 +361,11 @@ void kpowersave::loadIcon(bool forceReload){
 	if ((pixmap_name_tmp != pixmap_name) || (forceReload)) {
 		pixmap_name = pixmap_name_tmp;
 		if (pixmap_name.startsWith("ERROR")) {
-			pixmap = SmallIcon("laptoppower", width(), KIcon::DisabledState);
+			pixmap = SmallIcon("laptoppower", isShown() ? width() : 22, TDEIcon::DisabledState);
+		}
+		else {
+			pixmap = SmallIcon(pixmap_name, isShown() ? width() : 22);
 		}
-		else
-			pixmap = SmallIcon(pixmap_name, width());
 	}
 
 	kdDebugFuncOut(trace);
@@ -435,7 +436,9 @@ void kpowersave::drawIcon(){
 		}
 	}
 quit:
-	image = image.smoothScale(width(), height());
+	if (isShown()) {
+		image = image.smoothScale(width(), height());
+	}
 	fullIcon.convertFromImage(image);
 	setPixmap(fullIcon);
 
@@ -510,7 +513,7 @@ void kpowersave::updateTooltip(){
 /*!
  * \b TQT_SLOT to starts the Yast2-power-management module. This called by the menuentry
  * with ID \ref YAST_MODULE_MENU_ID, named "Start YaST2 Power Management Module".
- * It create a new KProcess and execute "/sbin/yast2 power-management" with kdesu.
+ * It create a new TDEProcess and execute "/sbin/yast2 power-management" with tdesu.
  */
 void kpowersave::do_config(){
 	kdDebugFuncIn(trace);
@@ -518,12 +521,12 @@ void kpowersave::do_config(){
 	#ifdef ENABLE_YAST_ENTRY
 	delete yast2;
 
-	yast2 = new KProcess;
-	*yast2 << "kdesu" << "--nonewdcop" << "/sbin/yast2" << "power-management";
+	yast2 = new TDEProcess;
+	*yast2 << "tdesu" << "--nonewdcop" << "/sbin/yast2" << "power-management";
 
-	connect(yast2, TQT_SIGNAL(processExited(KProcess *)),
-	         TQT_SLOT(slotConfigProcessExited(KProcess *)));
-	if(!yast2->start(KProcess::NotifyOnExit))
+	connect(yast2, TQT_SIGNAL(processExited(TDEProcess *)),
+	         TQT_SLOT(slotConfigProcessExited(TDEProcess *)));
+	if(!yast2->start(TDEProcess::NotifyOnExit))
 	{
 		delete yast2;
 		yast2 = NULL;
@@ -549,7 +552,7 @@ void kpowersave::slotHelp()
  */
 void kpowersave::slotAbout()
 {
- 	KAboutApplication a( this );
+ 	TDEAboutApplication a( this );
         a.exec();
 }
 
@@ -648,10 +651,10 @@ void kpowersave::observeConfigDlg(){
 }
 
 /*!
- * \b TQT_SLOT which called from \ref do_config() if the 'kdesu yast2' KProcess exited.
+ * \b TQT_SLOT which called from \ref do_config() if the 'tdesu yast2' TDEProcess exited.
  * This function control the return value and display if needed a errormessage on failure.
  */
-void kpowersave::slotConfigProcessExited(KProcess *proc){
+void kpowersave::slotConfigProcessExited(TDEProcess *proc){
 	kdDebugFuncIn(trace);
 
 	#ifdef ENABLE_YAST_ENTRY
@@ -1299,7 +1302,7 @@ void kpowersave::_quit (){
 }
 
 /*!
- * \b TQT_SLOT called if the user select a 'CPU Frequency Policy' from the menu ( \ref CPUFRETQ_MENU_ID ).
+ * \b TQT_SLOT called if the user select a 'CPU Frequency Policy' from the menu ( \ref CPUFREQ_MENU_ID ).
  */
 void kpowersave::do_setSpeedPolicy(int menu_id){
 	if (trace) kdDebug() << funcinfo << "IN: " << "menu_id/set policy to: " << menu_id << endl;
@@ -1452,9 +1455,9 @@ void kpowersave::updateCPUFreqMenu(){
 	if (hwinfo->supportCPUFreq() && hwinfo->isOnline() && hwinfo->isCpuFreqAllowed()) {
 		/* set CPU frequency menu entries *********/
 		/* speed menu has id 3 in context menu */
-		contextMenu()->setItemVisible(CPUFRETQ_MENU_ID, true);
-		contextMenu()->setItemEnabled(CPUFRETQ_MENU_ID, true);
-		contextMenu()->setItemVisible(CPUFRETQ_SEPARATOR_MENU_ID, true);
+		contextMenu()->setItemVisible(CPUFREQ_MENU_ID, true);
+		contextMenu()->setItemEnabled(CPUFREQ_MENU_ID, true);
+		contextMenu()->setItemVisible(CPUFREQ_SEPARATOR_MENU_ID, true);
 
 		switch (hwinfo->getCurrentCPUFreqPolicy()){
 			case PERFORMANCE:
@@ -1478,13 +1481,13 @@ void kpowersave::updateCPUFreqMenu(){
 		if (!speed_menu) {
 			return ;
 		} else if (hwinfo->supportCPUFreq() && (hwinfo->isCpuFreqAllowed() != 1)) {
-			contextMenu()->setItemEnabled(CPUFRETQ_MENU_ID, false);
-			contextMenu()->setItemVisible(CPUFRETQ_SEPARATOR_MENU_ID, true);
+			contextMenu()->setItemEnabled(CPUFREQ_MENU_ID, false);
+			contextMenu()->setItemVisible(CPUFREQ_SEPARATOR_MENU_ID, true);
 		} else{
 			/* there were CPU freq policies, but they are not accessible any more */
 			/* delete speed_menu */
-			contextMenu()->setItemVisible(CPUFRETQ_MENU_ID, false);
-                        contextMenu()->setItemVisible(CPUFRETQ_SEPARATOR_MENU_ID, false);
+			contextMenu()->setItemVisible(CPUFREQ_MENU_ID, false);
+                        contextMenu()->setItemVisible(CPUFREQ_SEPARATOR_MENU_ID, false);
 		}
 	}
 
@@ -1861,7 +1864,7 @@ void kpowersave::setSchemeSettings(){
 	}
 
 	// --> set CPU Freq settings
-	if(hwinfo->supportCPUFreq()) {
+	if(hwinfo->supportCPUFreq() && hwinfo->isCpuFreqAllowed()) {
 		hwinfo->setCPUFreq( settings->cpuFreqPolicy, settings->cpuFreqDynamicPerformance);
 	}
 
@@ -2088,13 +2091,13 @@ void kpowersave::handleActionCall ( action action, int value , bool checkAC, boo
 			case BRIGHTNESS:
 				hwinfo->setBrightness( -1, value );
 				break;
-			case CPUFRETQ_POWERSAVE:
+			case CPUFREQ_POWERSAVE:
 				hwinfo->setCPUFreq( POWERSAVE );
 				break;
-			case CPUFRETQ_DYNAMIC:
+			case CPUFREQ_DYNAMIC:
 				hwinfo->setCPUFreq( DYNAMIC, settings->cpuFreqDynamicPerformance );
 				break;
-			case CPUFRETQ_PERFORMANCE:
+			case CPUFREQ_PERFORMANCE:
 				hwinfo->setCPUFreq( PERFORMANCE );
 				break;
 			case SWITCH_SCHEME: // not supported atm
@@ -2250,7 +2253,7 @@ void kpowersave::handleResumeSignal() {
 	setAutoDimm(true);
 
 	// reset the CPU Freq Policy ... for more see https://bugzilla.novell.com/show_bug.cgi?id=223164
-	if(hwinfo->supportCPUFreq()) {
+	if(hwinfo->supportCPUFreq() && hwinfo->isCpuFreqAllowed()) {
 		hwinfo->setCPUFreq( settings->cpuFreqPolicy, settings->cpuFreqDynamicPerformance );
 	}
 
